@@ -22,8 +22,7 @@
 
 #include <plugins/project-wizard/values.h>
 
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkbutton.h>
+#include <gtk/gtk.h>
 
 #include <glib-object.h>
 
@@ -81,7 +80,7 @@ typedef void(*CgElementEditorTransformFunc) (GHashTable *, gpointer);
  * eventually. */
 void cg_element_editor_set_values (CgElementEditor *editor,
                                    const gchar *name,
-                                   NPWValueHeap *values,
+                                   GHashTable *values,
                                    CgElementEditorTransformFunc func,
                                    gpointer user_data,
                                    ...);
@@ -90,7 +89,7 @@ typedef gboolean(*CgElementEditorConditionFunc) (const gchar **, gpointer);
 
 void cg_element_editor_set_value_count (CgElementEditor *editor,
                                         const gchar *name,
-                                        NPWValueHeap *values,
+                                        GHashTable *values,
                                         CgElementEditorConditionFunc func,
                                         gpointer user_data);
 
